@@ -8,14 +8,15 @@ import json
 
 SERNIORITY_VALUES = ["all", "senior", "junior"]
 STAGE_VALUES = [None, "NEW", "YES", "LATER", "NO"]
-SORT_BY_VALUES = [None, "creation", "DESC", "reception", "ranking"]
+SORT_BY_VALUES = [None, "reception", "ranking"]
+ORDER_BY_VALUES = [None, "desc", "asc"]
 VALID_EXTENSIONS = ['.pdf', '.png', '.jpg', '.jpeg', '.bmp', '.doc', '.docx', '.rtf', '.dotx', '.odt', '.odp', '.ppt', '.pptx', '.rtf', '.msg']
 INVALID_FILENAME = ['.', '..']
 TRAINING_METADATA_MANDATORY_FIELD = {'filter_reference': lambda x: _validate_filter_reference(x, False),
-                                    'stage': lambda x: _validate_stage(x),
-                                    'stage_timestamp': lambda x: _validate_timestamp(x, 'stage_timestamp'),
-                                    'rating': lambda x: _validate_rating(x),
-                                    'rating_timestamp': lambda x: _validate_rating(x)}
+                                     'stage': lambda x: _validate_stage(x),
+                                     'stage_timestamp': lambda x: _validate_timestamp(x, 'stage_timestamp'),
+                                     'rating': lambda x: _validate_rating(x),
+                                     'rating_timestamp': lambda x: _validate_rating(x)}
 TIMESTAMP_NOW = str(time.time())
 
 
@@ -62,11 +63,12 @@ class Profile(object):
         self.parsing = ProfileParsing(self.client)
         self.scoring = ProfileScoring(self.client)
         self.rating = ProfileRating(self.client)
+        self.revealing = ProfileRevealing(self.client)
         self.json = ProfileJson(self.client)
 
     def list(self, source_ids=None, seniority="all", stage=None,
-            date_start="1494539999", date_end=TIMESTAMP_NOW, filter_id=None,
-            page=1, limit=30, sort_by='ranking', filter_reference=None, order_by=None):
+             date_start="1494539999", date_end=TIMESTAMP_NOW, filter_id=None,
+             page=1, limit=30, sort_by='reception', filter_reference=None, order_by=None):
         """
         Retreive all profiles that match the query param.
 
@@ -103,7 +105,7 @@ class Profile(object):
         query_params["sort_by"] = _validate_sort_by(sort_by)
         query_params["source_ids"] = json.dumps(_validate_source_ids(source_ids))
         query_params["stage"] = _validate_stage(stage)
-        query_params["order_by"] = order_by
+        query_params["order_by"] = _validate_order_by(order_by)
 
         response = self.client.get("profiles", query_params)
         return response.json()
@@ -150,8 +152,8 @@ class Profile(object):
         for file_path in files_to_send:
             try:
                 resp = self.add(source_id=source_id,
-                    file_path=file_path, profile_reference="",
-                    timestamp_reception=timestamp_reception, training_metadata=training_metadata)
+                                file_path=file_path, profile_reference="",
+                                timestamp_reception=timestamp_reception, training_metadata=training_metadata)
                 if resp['code'] != 200 and resp['code'] != 201:
                     failed_upload[file_path] = ValueError('Invalid response: ' + str(resp))
                 else:
@@ -369,6 +371,43 @@ class ProfileRating():
         return response.json()
 
 
+class ProfileRevealing():
+    """Manage interpretability related profile calls."""
+
+    def __init__(self, api):
+        """Init."""
+        self.client = api
+
+    def get(self, source_id=None, profile_id=None, profile_reference=None, filter_id=None, filter_reference=None):
+        """
+        Retrieve the interpretability information.
+
+        Args:
+            source_id:              <string>
+                                    source id
+            profile_id:             <string>
+                                    profile id
+            filter_id:              <string>
+                                    filter id
+
+        Returns
+            interpretability information
+
+        """
+        query_params = {}
+        query_params["source_id"] = _validate_source_id(source_id)
+        if profile_id:
+            query_params["profile_id"] = _validate_profile_id(profile_id)
+        if profile_reference:
+            query_params["profile_reference"] = _validate_profile_reference(profile_reference)
+        if filter_id:
+            query_params["filter_id"] = _validate_filter_id(filter_id)
+        if filter_reference:
+            query_params["filter_reference"] = _validate_filter_reference(filter_reference)
+        response = self.client.get('profile/revealing', query_params)
+        return response
+
+
 class ProfileJson():
     """Gathers route about structured profile."""
 
@@ -396,7 +435,7 @@ class ProfileJson():
 
         # some enrichement for profile_json
         if timestamp_reception is not None:
-            data['profile_json']['timestamp_reception'] = _validate_timestamp(timestamp_reception, 'timestamp_reception')
+            data['timestamp_reception'] = _validate_timestamp(timestamp_reception, 'timestamp_reception')
 
         response = self.client.post("profile/json", data=data)
         return response.json()
@@ -525,6 +564,13 @@ def _validate_rating(value):
     return value
 
 
+def _validate_order_by(value):
+    if value not in ORDER_BY_VALUES:
+        raise ValueError("order_by value must be in {}".format(str(ORDER_BY_VALUES)))
+
+    return value
+
+
 def _validate_sort_by(value):
     if value not in SORT_BY_VALUES:
         raise ValueError("sort_by value must be in {}".format(str(SORT_BY_VALUES)))
@@ -544,7 +590,7 @@ def _is_valid_extension(file_path):
     ext = path.splitext(file_path)[1]
     if not ext:
         return False
-    return ext in VALID_EXTENSIONS
+    return (ext in VALID_EXTENSIONS or ext.lower() in VALID_EXTENSIONS)
 
 
 def _is_valid_filename(file_path):
